//
//  KenteiViewController.swift
//  VeseKentei
//
//  Created by Sachico Kuwamura on 2015/03/26.
//  Copyright (c) 2015年 Haruyoshi Kuwamura. All rights reserved.
//

import UIKit

class KenteiViewController: UIViewController {
    
    @IBOutlet weak var mondaiNumberLabel: UILabel!
    @IBOutlet weak var mondaiTextView: UITextView!
    @IBOutlet weak var answerBtn1: UIButton!
    @IBOutlet weak var answerBtn2: UIButton!
    @IBOutlet weak var answerBtn3: UIButton!
    @IBOutlet weak var answerBtn4: UIButton!
    @IBOutlet weak var judgeImageView: UIImageView!
    //kentei.csvファイルを格納する配列csvArray
    var csvArray = [String]()
    //csvArrayから取り出した問題を格納する配列mondaiArray
    var mondaiArray = [String]()
    
    var mondaiCount = 0     //問題をカウントする変数
    var correctCount = 0    //正解をカウントする変数
    let total = 10          //出題数を管理する定数
    
    //正解&解説バックグラウンド画像
    var kaisetsuBGImageView = UIImageView()
    //解説バックグラウンド画像のX座標
    var kaisetsuBGX = 0.0
    //正解表示ラベル
    var seikaiLabel = UILabel()
    //解説テキストビュー
    var kaisetsuTextView = UITextView()
    //バックボタン
    var backBtn = UIButton()
    //SEManager
    var soundManager = SEManager()
    
    
    //viewDidLoadメソッド
    override func viewDidLoad() {
        super.viewDidLoad()
        //バックグラウンド画像をセット
        kaisetsuBGImageView.image = UIImage(named: "kaisetsuBG.png")
        //画面サイズを取得
        let screenSize:CGSize = (UIScreen.mainScreen().bounds.size)
        //解説バックグラウンド画像のx座標(画面の中央になるように設定)
        kaisetsuBGX = Double(screenSize.width/2) - 320/2
        
        //フレームを設定。Y座標に画面の縦サイズを設定して、画面の外に設置する。
        kaisetsuBGImageView.frame = CGRect(x: kaisetsuBGX, y: Double(screenSize.height), width: 320, height: 210)
        
        
        
        ///画像のタッチ操作を可能にする
        kaisetsuBGImageView.userInteractionEnabled = true
        //画像をviewに配置
        self.view.addSubview(kaisetsuBGImageView)
        
        //正解表示ラベルのフレームを設定
        seikaiLabel.frame = CGRect(x: 10, y: 5, width: 300, height: 30)
        //正解表示ラベルのアラインメントをセンターに設定
        seikaiLabel.textAlignment = .Center
        //正解ラベルのフォントサイズを15ポイントに設定
        seikaiLabel.font = UIFont.systemFontOfSize(CGFloat(15))
        //正解ラベルを解説バックグラウンド画像に配置
        kaisetsuBGImageView.addSubview(seikaiLabel)
        
        //解説テキストビューのフレームを設定
        kaisetsuTextView.frame = CGRect(x: 10, y: 40, width: 300, height: 140)
        //解説テキストビューの背景色を透明に設定
        kaisetsuTextView.backgroundColor = UIColor.clearColor()
        //解説テキストビューのフォントサイズを17ポイントに設定
        kaisetsuTextView.font = UIFont.systemFontOfSize(CGFloat(17))
        //解説テキストビューを編集できないようにする
        kaisetsuTextView.editable = false
        //解説テキストビューを解説バックグラウンド画像に配置
        kaisetsuBGImageView.addSubview(kaisetsuTextView)
        
        //バックボタンのフレームを設定
        backBtn.frame = CGRect(x: 10, y: 180, width: 300, height: 30)
        //バックボタンに通常時と押下時の画像を設定
        backBtn.setImage(UIImage(named: "kenteiBack.png"), forState: .Normal)
        backBtn.setImage(UIImage(named: "kenteiBackOn.png"), forState: .Highlighted)
        //バックボタンにアクション設定
        backBtn.addTarget(self, action: "backBtnTapped", forControlEvents: UIControlEvents.TouchUpInside)
        //バックボタンを解説バックグラウンド画像に配置
        kaisetsuBGImageView.addSubview(backBtn)
        
        //変数viewControllerを作成
        let viewController = ViewController()
        //loadCSVメソッドを使用し、csvArrayに検定問題を格納
        csvArray = viewController.loadCSV("kentei")
        //シャッフルメソッドを使用し、検定問題を並び替えてcsvArrayに格納
        csvArray = mondaiShuffle()
        
        //csvArrayの0行目を取り出し、カンマを区切りとしてmondaiArrayに格納
        mondaiArray = csvArray[mondaiCount].componentsSeparatedByString(",")
        //変数mondaiCountに1を足してラベルに出題数を設定。
        mondaiNumberLabel.text = "第\(mondaiCount+1)問"
        //TextViewに問題を設定
        mondaiTextView.text = mondaiArray[0]
        //選択肢ボタンのタイトルに選択肢を設定
        answerBtn1.setTitle(mondaiArray[2], forState: .Normal)
        answerBtn2.setTitle(mondaiArray[3], forState: .Normal)
        answerBtn3.setTitle(mondaiArray[4], forState: .Normal)
        answerBtn4.setTitle(mondaiArray[5], forState: .Normal)
    }
    //四択ボタンを押したときのメソッド
    @IBAction func btnAction(sender: UIButton){
        //正解番号とボタンのtagが同じなら正解(.toInt()を使ってキャスト)。
        if sender.tag == Int(mondaiArray[1]){
            //⚪︎を表示
            judgeImageView.image = UIImage(named: "maru.png")!
            //SEManagerクラスのsePlayメソッドで正解音を鳴らす
            soundManager.sePlay("right.mp3")
            //正解カウントを増やす
            correctCount++
        }else {
            //間違っていたら×を表示
            judgeImageView.image = UIImage(named: "batsu.png")!
            //SEManagerクラスのsePlayメソッドで不正解音を鳴らす
            soundManager.sePlay("mistake.mp3")
        }
        //judgeImageViewを表示
        judgeImageView.hidden = false
        //kaisetsuメソッドを呼び出し
        kaisetsu()
    }
    //次の問題を表示するメソッド
    func nextProblem(){
        //問題カウント変数をカウントアップ
        mondaiCount++
        //mondaiArrayに格納されている問題配列を削除
        mondaiArray.removeAll(keepCapacity: true)
        //if-else文を追加。mondaiCountがtotalに達したら画面遷移
        if mondaiCount < total{
            //csvArrayから次の問題配列をmondaiArrayに格納
            mondaiArray = csvArray[mondaiCount].componentsSeparatedByString(",")
            //問題数ラベル、問題表示テキストビュー、選択肢ボタンに情報をセット
            mondaiNumberLabel.text = "第\(mondaiCount+1)問"
            mondaiTextView.text = mondaiArray[0]
            answerBtn1.setTitle(mondaiArray[2], forState: .Normal)
            answerBtn2.setTitle(mondaiArray[3], forState: .Normal)
            answerBtn3.setTitle(mondaiArray[4], forState: .Normal)
            answerBtn4.setTitle(mondaiArray[5], forState: .Normal)
        }else{
            //Storyboard SegueのIdentifierを引数に設定して画面遷移
            performSegueWithIdentifier("score", sender: nil)
        }
    }
    //解説表示メソッド
    func kaisetsu(){
        //正解表示ラベルのテキストをmondaiArrayから取得
        seikaiLabel.text = mondaiArray[6]
        //解説テキストビューのテキストをmondaiArrayから取得
        kaisetsuTextView.text = mondaiArray[7]
        //answerBtn1のy座標を取得
        let answerBtnY = answerBtn1.frame.origin.y
        //解説バックグラウンド画像を表示させるアニメーション
        UIView.animateWithDuration(0.5, animations: {() -> Void in self.kaisetsuBGImageView.frame = CGRect(x: self.view.bounds.width/2 - 320/2, y: answerBtnY, width: 320, height: 210);})
        //選択肢ボタンの使用停止
        answerBtn1.enabled = false
        answerBtn2.enabled = false
        answerBtn3.enabled = false
        answerBtn4.enabled = false
    }
    //バックボタンメソッド
    func backBtnTapped(){
        //画面の縦サイズを取得
        let screenHeight = Double(UIScreen.mainScreen().bounds.size.height)
        //解説バックグラウンド画像を枠外に移動させるアニメーション
        UIView.animateWithDuration(0.5, animations: {() -> Void in
            self.kaisetsuBGImageView.frame = CGRect(x:self.kaisetsuBGX, y: screenHeight, width: 320, height: 210)
        })
        //選択肢ボタンの使用を再開
        answerBtn1.enabled = true
        answerBtn2.enabled = true
        answerBtn3.enabled = true
        answerBtn4.enabled = true
        //正誤表示画像を隠す
        judgeImageView.hidden = true
        //nextProblemメソッドを呼び出す
        nextProblem()
    }
    //得点画面へ値を渡す
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject!) {
        
        let sVC = segue.destinationViewController as! ScoreViewController
        sVC.correct = correctCount
    }
    //配列シャッフルメソッド
    func mondaiShuffle()->[String]{
        //String型の配列を宣言
        var array = [String]()
        //csvArrayをNSMutableArrayに変換してsortedArrayに格納
        let sortedArray = NSMutableArray(array: csvArray)
        //sortedArrayの配列数を取得
        var arrayCount = sortedArray.count
        //while文で配列の数繰り返す
        while(arrayCount > 0){
            //ランダムなインデックス番号を取得するため配列数の範囲で乱数を作る
            let randomIndex = arc4random() % UInt32(arrayCount)
            //sortedArrayのarrayCount番号とランダム番号を入れ替える
            sortedArray.exchangeObjectAtIndex((arrayCount-1), withObjectAtIndex: Int(randomIndex))
            //arrayCountを1減らす
            arrayCount = arrayCount-1
            //sortedArrayのarrayCount番号をString型に変換して配列arrayに追加
            array.append(sortedArray[arrayCount] as! String)
        }
        //arrayを戻り値
        return array
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    
    /*
    // MARK: - Navigation
    
    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
    // Get the new view controller using segue.destinationViewController.
    // Pass the selected object to the new view controller.
    }
    */
    
}
