//
//  ViewController.swift
//  NewsReader
//
//  Created by 桑村 治良 on 2015/02/09.
//  Copyright (c) 2015年 KuwamuraHaruyoshi. All rights reserved.
//

import UIKit
//Alamofireライブラリをインポート
import Alamofire


//UITableViewDataSourceとUITableViewDelegateを追加
class ViewController: UIViewController,UITableViewDataSource,UITableViewDelegate {
    //ニュース一覧データを格納する配列
    var newsDataArray = NSArray()
    //テーブルビューのインスタンス
    @IBOutlet var table :UITableView!
    //ニュース記事のURLを格納するString変数
    var newsUrl = ""
    //ニュース記事の配信元を格納するString変数
    var publisher = ""

    override func viewDidLoad() {
        super.viewDidLoad()
        //ViewControllerのタイトルを設定
        self.title = "News Reader"
        // Table ViewのDataSource参照先指定
        table.dataSource = self
        // Table Viewのタップ時のdelegate先を指定
        table.delegate = self

        //ニュース情報の取得先
        let requestUrl = "https://ajax.googleapis.com/ajax/services/search/news?v=1.0&topic=p&hl=ja&rsz=8"
        //Webサーバに対してHTTP通信のリクエストを出してデータを取得

        Alamofire.request(.GET, requestUrl, parameters: ["foo": "bar"])
            .responseJSON { response in
                if let json = response.result.value {
                    //まずJSONデータをNSDictionary型に
                    let jsonDic = json as! NSDictionary
                    //辞書化したjsonDicからキー値"responseData"を取り出す
                    let responseData = jsonDic["responseData"] as! NSDictionary
                    //responseDataからキー値"results"を取り出す
                    self.newsDataArray = responseData["results"] as! NSArray
                    //ニュース記事を取得したらテーブルビューに表示
                    self.table.reloadData()

                }
        }
    }
    //テーブルビューのセルの数をnewsDataArrayに格納しているデータの数で設定
    func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return newsDataArray.count
    }
    //セルに表示する内容を設定
    func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        // StoryBoardで取得したCellを取得
        let cell = UITableViewCell(style: UITableViewCellStyle.Subtitle, reuseIdentifier: "Cell")
        // ニュース記事データを取得（配列の要素で"indexPath.row"番目の要素を取得）
        let newsDic = newsDataArray[indexPath.row] as! NSDictionary
        // タイトルとタイトルの行数、公開日時をCellにセット
        cell.textLabel?.text = newsDic["title"] as? String
        cell.textLabel?.numberOfLines = 3
        cell.detailTextLabel?.text = newsDic["publishedDate"] as? String
        return cell
    }
    
    //テーブルビューのセルがタップされた処理を追加
    func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
        // ニュース記事データを取得（配列の要素で"indexPath.row"番目の要素を取得）
        let newsDic = newsDataArray[indexPath.row] as! NSDictionary
        // ニュース記事のURLを取得
        newsUrl = newsDic["unescapedUrl"] as! String
        //ニュースの配信元名を取得
        publisher = newsDic["publisher"] as! String
        //WebViewControllerへ遷移
        performSegueWithIdentifier("toWebView", sender: self)
    }
    //WebViewControllerへURLデータを渡す
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        //セグエ用にダウンキャストしたWebViewControllerのインスタンス
        let wvc = segue.destinationViewController as! WebViewController
        //変数newsUrlの値をWebViewControllerの変数newsUrlに代入
        wvc.newsUrl = newsUrl
        //titleプロパティでWebViewControllerのタイトルにpublisherを代入
        wvc.title = publisher
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }


}

